# Generated by roxygen2: do not edit by hand

S3method(coef,lmCoDa)
S3method(confint,lmCoDa)
S3method(fitted,lmCoDa)
S3method(predict,lmCoDa)
S3method(residuals,lmCoDa)
export(CoDa_path)
export(CoDa_seq)
export(Impacts)
export(ShareRatioElasticities)
export(ToSimplex)
export(VariationScenario)
export(VariationTable)
export(alr)
export(alrInv)
export(clr)
export(clrInv)
export(ilr)
export(ilrInv)
export(lmCoDa)
importFrom(compositions,alr)
importFrom(compositions,alrInv)
importFrom(compositions,clr)
importFrom(compositions,clrInv)
importFrom(compositions,ilr)
importFrom(compositions,ilrInv)
importFrom(methods,as)
importFrom(methods,is)
importFrom(stats,coef)
importFrom(stats,fitted)
importFrom(stats,nobs)
importFrom(stats,qt)
importFrom(stats,resid)
